/*

DESCRIPTION:
    Main include file for OAT project.

SYNTAX:  n/a

KNOWN BUGS:  n/a.

COPYRIGHT:  (c) 2018, Brian Cornell, all rights reserved.

DEPENDENCIES:  none

VERSION:  1.0, development release

MODIFICATION HISTORY:

    26 Jan 18, BWC, created file.


*/



//#define _DEBUG                              //Uncomment for conditional testing


/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 *                      Version constants & definitions
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
#define VERMAJOR                1
#define VERMINOR                0
#define VERBUILD                2


/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 * System wide constants & definitions.  Convention:  S_<TYPE>_<INFO>
 * Types:
 *  + DC=Duty Cycle
 *  + EN=ENable bit
 *  + RT=RaTio of a voltage presented to PIC, internal or external
 *  + LM=LiMiting operational value
 *  + TM=TiMing
 *  + MP=Peripheral port bit MaPping
 *  + QY=quantity (count) of something
 *  + CD=command data
 *  + BL=boolean value
 * 
 * Info is user defined and should be descriptive.
 * 
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
#define S_TM_INT                100     //#mS to wait after initialization
#define S_TM_SETTLE             1000    //#mS to wait after waking up
#define S_QY_TMP_SAMPLES        7       //# of temp readings per sample
#define S_QY_TMP_COEFF          20      //Temp coefficient:  temp sense mv/C / ADC uV/bit
#define S_QY_TMP_0COFFS         50      //0C offset for temperature calculation
#define S_QY_F_CONVN            9       //Numerator for Fahrenheit conversion
#define S_QY_F_CONVD            5       //Denominator for Fahrenheit conversion
#define S_QY_F_OFFS             32      //Freezing offset for Fahrenheit conversion
#define S_EN_UNITS              WPUC0   //Register bit controlling pin RC0 weak pull-up


/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 * Analog channel mapping:  channel=port=pin.  The values assigned to these
 * constants should match those used by ADC and bit-aligned for direct loading
 * into ADC control register.  Channels available depend on specific chip.
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
#define ANL_CH_RC7              0x17        //Pin RC7


/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 *                           PPS & direct pin mapping
 * 
 * For PPS output pin assignments both aliases for pin registers and constants 
 * mapping what peripheral connects to the pin.
 *      Pin register alias convention:  PPS_P_XXX_YY where
 *          XXX=peripheral name
 *          YY=channel or other detail; can be omitted
 *      Peripheral mapping convention:  PPS_M_XXX_YY same as alias
 * 
 * Input pins only require mapping constant.
 * 
 * For pins accessed directly or assigned in a peripheral's register (like ADC)
 * use the following convention:  PIN_X_YYYYYY where
 *          X=Input or Output
 *          YYYYYY=user assigned mnemonic describing function
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
#define PIN_I_UNITS             RC0         //Pin RC0 selects C or F display
#define PIN_O_TMPWR             RC1         //Pin RC1 powers temp sense & units select


/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 * Port/pin configuration:  I/O, analog/digital, slew rate, etc.
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
//Port I/O:  1=input, 0=output
#define IO_PORTA                0b00100000
#define IO_PORTB                0b00000000
#define IO_PORTC                0b11100001
#define IO_PORTE                0b11111111
//Port Analog/Digital:  1=analog, 0=digital
#define AD_PORTA                0b00000000
#define AD_PORTB                0b00000000
#define AD_PORTC                0b11100000
#define AD_PORTE                0b11110111

//Port weak pull-up:  1=enabled, 0=disabled
#define WP_PORTA                0b00000000
#define WP_PORTB                0b00000000
#define WP_PORTC                0b00000000
#define WP_PORTE                0b00000000
//Open drain:  1=open drain, 0=push-pull
#define OD_PORTA                0b00000000
#define OD_PORTB                0b00000000
#define OD_PORTC                0b00000000
#define OD_PORTE                0b00000000
//Slew rate:  1=limited, 0=maximum
#define SR_PORTA                0b00000000
#define SR_PORTB                0b00000000
#define SR_PORTC                0b00000000
#define SR_PORTE                0b00000000
//Input level:  1=ST, 0=TLL
#define IL_PORTA                0b00000000
#define IL_PORTB                0b00000000
#define IL_PORTC                0b00000000
#define IL_PORTE                0b00000000
//Port values to initially set output latches to
#define VL_PORTA                0b00000000
#define VL_PORTB                0b00000000
#define VL_PORTC                0b00000000
#define VL_PORTE                0b00000000


/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 *                            Macro functions
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
//Hack for interrupts because these don't seem to compile for this chip
#define di()            GIE = 0             //Disable interrupts
#define ei()            GIE = 1             //Enable interrupts


/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 * ADC configuration & acquisition constants
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
#define CFG_ADC_CON0            0x04        //Disabled, Fosc clock, R-justified results,
#define CFG_ADC_CON1            0x00        //Single conversion for each trigger
#define CFG_ADC_CON2            0x00        //Basic mode
#define CFG_ADC_CON3            0x00        //RES-PREV, GO not cleared in HW, never interrupt
#define CFG_ADC_CLK             0x00        //Fosc/2
#define CFG_ADC_REF             0x03        //Vref=FVR
#define CFG_ADC_PCH             ANL_CH_RC7  //Positive channel selection
#define CFG_ADC_PRE             0x0000      //Precharge time
#define CFG_ADC_ACQ             0x0000      //Acquisition time
#define CFG_ADC_CAP             0x00        //No additional acquisition capacitance
#define CFG_ADC_RPT             0x00        //Repeat count for LP filter
#define CFG_ADC_ACT             0x00        //No auto-conversion trigger

//Internal channels (peripherals)
#define ADC_CH_VLCD3            0x39        //VLCD3 pin / 4
#define ADC_CH_VBAT             0x3A        //Vbat / 3
#define ADC_CH_AVSS             0x3B        //Analog Vss
#define ADC_CH_ITMP             0x3C        //Internal temperature sensor
#define ADC_CH_DAC1             0x3D        //DAC1 output
#define ADC_CH_FVR1             0x3E        //FVR1 buffer
#define ADC_CH_FVR2             0x3F        //FVR2 buffer


/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 * Configure system clock.  Expects 1MHz HFINTOSC to be active at boot.
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
#define _XTAL_FREQ      1000000         //Must match Fosc to use __delayxxx macros


/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 * FVR & DAC configuration constants
 * FVR:  ADC positive reference
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
#define CFG_FVR_CON             0x82    //Enabled, ADC 2x gain
#define FI_FVR_DLY              30      //Time delay in uS for FVR buffer to stabilize


/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 * Watchdog configuration constants
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
#define CFG_WCHD_CON0           0x1A    //8s interval, disabled
#define CFG_WCHD_CON1           0x07    //LFINTOSC, window open 100%


/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 * LCD module configuration constants
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
#define CFG_LCD_CON             0x01    //Disabled, drives in sleep, LFINTOSC, static mux
#define CFG_LCD_PS              0x07    //Type A waveform, 1:16 prescale
#define CFG_LCD_SEG0            0xFF    //Segments 0-7 enabled
#define CFG_LCD_SEG1            0xFF    //Segments 8-5 enabled
#define CFG_LCD_SEG2            0x1C    //Segments 18-20 enabled
#define CFG_LCD_VC2             0x08    //Voltage supplied on VLCD3
#define CFG_LCD_DAT0            0x00    //Segments 0-7 initial data
#define CFG_LCD_DAT1            0x00    //Segments 8-5 initial data
#define CFG_LCD_DAT2            0x00    //Segments 18-20 initial data


/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 * LCD segment display character map:  bit mapping of 'on' segments for num/chr
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
#define LCD_CHR_0               0x7F    //Zero
#define LCD_CHR_1               0x06    //One
#define LCD_CHR_2               0xBB    //Two
#define LCD_CHR_3               0x8F    //Three
#define LCD_CHR_4               0xC6    //Four
#define LCD_CHR_5               0xCD    //Five
#define LCD_CHR_6               0xFD    //Six
#define LCD_CHR_7               0x07    //Seven
#define LCD_CHR_8               0xFF    //Eight
#define LCD_CHR_9               0xCF    //Nine
#define LCD_CHR_BLK             0x00    //Blank
#define LCD_CHR_NEG             0x10    //Negative flag
#define LCD_CHR_POS             0x00    //Positive flag


/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 * LCD character map:  array position for displaying respective value
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
#define LCD_MAP_0               0       //Zero
#define LCD_MAP_1               1       //One
#define LCD_MAP_2               2       //Two
#define LCD_MAP_3               3       //Three
#define LCD_MAP_4               4       //Four
#define LCD_MAP_5               5       //Five
#define LCD_MAP_6               6       //Six
#define LCD_MAP_7               7       //Seven
#define LCD_MAP_8               8       //Eight
#define LCD_MAP_9               9       //Nine
#define LCD_MAP_BLK             10      //Blank


/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 * Peripheral module configuration constants to lower power demand
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
#define CFG_PMD_0               0x25    //Clock tuning, NVM access, interrupt on change
#define CFG_PMD_1               0x17    //Timers 4, 2, 1, 0 disabled
#define CFG_PMD_2               0xC7    //RTCC, DAC, CMP1/2, ZCD disabled
#define CFG_PMD_3               0x0F    //PWM3/4, CCP1/2 disabled
#define CFG_PMD_4               0xD1    //UART1/2, MSSP, CWG disabled
#define CFG_PMD_5               0x5E    //SMT, CLC1-4 disabled


/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 * Function declarations.  See source file for explanation of each function.
 *++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/
void main(void);
void Initialize(void);


//End of file